---
weight: 3
---

# How to Guides

## Integration with CircleCI

!!! note
    This guide is currently in development, 
    see [GH-10](https://github.com/ossiq/ossiq/issues/10) for more details.


## Integration with Github Actions

!!! note
    This guide is currently in development, 
    see [GH-5](https://github.com/ossiq/ossiq/issues/5) for more details.
